@@ -90,7 +90,8 @@ def _do_version_check():
     from packaging.version import Version
 
     from splitgraph.cloud import RESTAPIClient
-    from splitgraph.config import CONFIG, get_singleton
+    from splitgraph.config import CONFIG
+    from splitgraph.config.config import get_singleton
 
     api_client = RESTAPIClient(get_singleton(CONFIG, "SG_UPDATE_REMOTE"))
     latest = api_client.get_latest_version()
@@ -116,7 +117,7 @@ class WithExceptionHandler(click.Group):
         import psycopg2.extensions
         import psycopg2.extras
 
-        from splitgraph.engine import get_engine
+        from splitgraph.engine.config import get_engine
 
         # Allow users to send SIGINT to quickly terminate sgr (instead of waiting for a PG
         # statement to finish)
