@@ -359,7 +359,7 @@ def curl_c(remote, request_type, image, request_params, curl_args):
 
 
 def _get_ddn_conn_params(remote: str) -> Dict[str, Optional[str]]:
-    from splitgraph.engine import get_engine
+    from splitgraph.engine.config import get_engine
 
     try:
         engine = get_engine(remote)
@@ -1177,7 +1177,7 @@ def stub_c(remote, plugin_name, repository, output_file):
     if not plugin:
         raise click.UsageError("Plugin %s not found on remote %s" % (plugin_name, remote))
 
-    yml = ruamel.yaml.YAML()
+    yml = ruamel.yaml.main.YAML()
     output = stub_plugin(plugin, repository.namespace, repository.repository)
     yml.dump(output, output_file)
 
