@@ -29,14 +29,13 @@ from splitgraph.config import (
     FDW_CLASS,
     SPLITGRAPH_API_SCHEMA,
     SPLITGRAPH_META_SCHEMA,
-    get_singleton,
 )
+from splitgraph.config.config import get_singleton
 from splitgraph.core.fragment_manager import ExtraIndexInfo
 from splitgraph.core.image import Image
 from splitgraph.core.image_manager import ImageManager
-from splitgraph.core.sql import insert, select, validate_import_sql
 from splitgraph.core.table import Table
-from splitgraph.core.types import TableSchema
+from splitgraph.core.types import TableSchema, parse_repository
 from splitgraph.engine.postgres.engine import PostgresEngine
 from splitgraph.exceptions import (
     CheckoutError,
@@ -46,6 +45,8 @@ from splitgraph.exceptions import (
 )
 
 from ..engine import ResultShape
+from ..engine.config import get_engine
+from ..engine.utils import unmount_schema
 from .common import (
     aggregate_changes,
     gather_sync_metadata,
@@ -55,11 +56,12 @@ from .common import (
     set_head,
     set_tags_batch,
     slow_diff,
-    unmount_schema,
 )
-from .engine import get_engine, lookup_repository
+from .engine import lookup_repository
 from .object_manager import ObjectManager
 from .output import pluralise
+from .sql.queries import insert, select
+from .sql.splitfile_validation import validate_import_sql
 
 
 class Repository:
@@ -138,10 +140,7 @@ class Repository:
     @classmethod
     def from_schema(cls, schema: str) -> "Repository":
         """Convert a Postgres schema name of the format `namespace/repository` to a Splitgraph repository object."""
-        if "/" in schema:
-            namespace, repository = schema.split("/")
-            return cls(namespace, repository)
-        return cls("", schema)
+        return cls(*parse_repository(schema))
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Repository):
